@@ -35,7 +35,7 @@ exports.listActiveDocs = function(){
   });
 }
 
-exports.createActiveDocs = function(file){
+exports.createActiveDocs = function(file, system_name){
   var url = config.API+"/active_docs.json";
 
   //Parse swagger file and extract info from it
@@ -47,8 +47,8 @@ exports.createActiveDocs = function(file){
       url: url,
       form:{
         "access_token": config.access_token,
-        "name": api.info.title+n,
-        "system_name": slug(api.info.title+n),
+        "name": system_name || api.info.title+n,
+        "system_name": slug(system_name || api.info.title+n),
         "body": JSON.stringify(api),
         "description": api.info.description || "Activedocs file description",
         "published": true,
