@@ -8,14 +8,13 @@ var HttpError = require('http-error-constructor');
 
 exports.createService = function(name){
     var url = config.API+"/services.json";
-    var n = name+Math.floor((Math.random() * 50) + 10)
     var options ={
       method:'POST',
       url: url,
       form:{
         "access_token": config.access_token,
-        "name": n, //TODO get rid of random
-        "system_name": slug(n,"_")
+        "name": name,
+        "system_name": slug(name,"_")
       }
     };
     var response = request(options);
@@ -24,18 +23,13 @@ exports.createService = function(name){
      var res  = r[0].req.res;
      try {
        var body = JSON.parse(res.body);
+       console.log(body)
      } catch(e) {
      }
       if (res.statusCode >= 300) {
-        var err = new HttpError(res.statusCode)
-        var message = "ERROR encountered: "
-        if(body && body.error){ //error message in body
-          message += body.error
-        }else{
-          message += "["+res.statusCode+"] "+err.message
-        }
-        cli.error({message: message});
-        throw new Error("Server responded with status code " + res.statusCode);
+        cli.error({message:"ERROR encountered: " + JSON.stringify(body.errors || body.status)});
+        cli.debug({name: '3scale-cli:activedocs:delete', msg: 'ERROR:' +r[0].statusCode+" %o", data: (body.errors || body.status)})
+        throw new Error("Server responded with status code " + r[0].statusCode + " "+JSON.stringify(body.error || body.status));
       } else {
         config.add("threescale:service_id",body.service.id);
         return body.service;//assuming tapes are strings and not binary data
